@@ -65,7 +65,7 @@ void MultiplyingLineEditor::clear()
     }
 }
 
-bool MultiplyingLineEditor::isModified()
+bool MultiplyingLineEditor::isModified() const
 {
     return mModified || mView->isModified();
 }
@@ -121,34 +121,4 @@ QList<MultiplyingLine *> MultiplyingLineEditor::lines() const
     return mView->lines();
 }
 
-MultiplyingLine *MultiplyingLineEditor::activeLine() const
-{
-    return mView->activeLine();
-}
-
-void MultiplyingLineEditor::setFrameStyle(int shape)
-{
-    mView->setFrameStyle(shape);
-}
-
-void MultiplyingLineEditor::setAutoResizeView(bool resize)
-{
-    mView->setAutoResize(resize);
-}
-
-bool MultiplyingLineEditor::autoResizeView()
-{
-    return mView->autoResize();
-}
-
-void MultiplyingLineEditor::setDynamicSizeHint(bool dynamic)
-{
-    mView->setDynamicSizeHint(dynamic);
-}
-
-bool MultiplyingLineEditor::dynamicSizeHint() const
-{
-    return mView->dynamicSizeHint();
-}
-
 #include "moc_multiplyinglineeditor.cpp"
